abacusai.api_class.monitor — AbacusAI documentation

# `abacusai.api_class.monitor`

## Module Contents

### Classes

`ForecastingMonitorConfig` | Helper class that provides a standard way to create an ABC using

class abacusai.api_class.monitor.ForecastingMonitorConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  id_column: str
  timestamp_column: str
  target_column: str
  start_time: str
  end_time: str
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.